@@ -1,6 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 
 import numpy as np
 from astropy.io.fits.util import _is_int
@@ -9,7 +7,7 @@ from astropy.io.fits.util import _is_int
 __all__ = ['BoundingBox']
 
 
-class BoundingBox(object):
+class BoundingBox:
     """
     A rectangular bounding box in integer (not float) pixel indices.
 
@@ -216,3 +214,44 @@ class BoundingBox(object):
 
         return Rectangle(xy=(self.extent[0], self.extent[2]),
                          width=self.shape[1], height=self.shape[0], **kwargs)
+
+    def to_aperture(self):
+        """
+        Return a `~photutils.aperture.RectangularAperture` that
+        represents the bounding box.
+        """
+
+        from .rectangle import RectangularAperture
+
+        xpos = (self.extent[1] + self.extent[0]) / 2.
+        ypos = (self.extent[3] + self.extent[2]) / 2.
+        xypos = (xpos, ypos)
+        h, w = self.shape
+
+        return RectangularAperture(xypos, w=w, h=h, theta=0.)
+
+    def plot(self, origin=(0, 0), ax=None, fill=False, **kwargs):
+        """
+        Plot the `BoundingBox` on a matplotlib `~matplotlib.axes.Axes`
+        instance.
+
+        Parameters
+        ----------
+        origin : array_like, optional
+            The ``(x, y)`` position of the origin of the displayed
+            image.
+
+        ax : `matplotlib.axes.Axes` instance, optional
+            If `None`, then the current `~matplotlib.axes.Axes` instance
+            is used.
+
+        fill : bool, optional
+            Set whether to fill the aperture patch.  The default is
+            `False`.
+
+        kwargs
+            Any keyword arguments accepted by `matplotlib.patches.Patch`.
+        """
+
+        aper = self.to_aperture()
+        aper.plot(origin=origin, ax=ax, fill=fill, **kwargs)
