@@ -5,9 +5,6 @@ Here we test directly with aperture objects since we are checking the
 algorithms in aperture_photometry, not in the wrappers.
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 import pytest
 import numpy as np
 from numpy.testing import (assert_allclose, assert_array_equal,
@@ -17,8 +14,8 @@ from astropy.coordinates import SkyCoord
 from astropy.io import fits
 from astropy.nddata import NDData
 from astropy.table import Table
-from astropy.tests.helper import remote_data
 import astropy.units as u
+from astropy.utils import minversion
 from astropy.wcs.utils import pixel_to_skycoord
 
 from ..core import aperture_photometry
@@ -37,6 +34,7 @@ try:
 except ImportError:
     HAS_MATPLOTLIB = False
 
+NUMPY_LT_1_14 = not minversion('numpy', '1.14dev')
 
 APERTURE_CL = [CircularAperture,
                CircularAnnulus,
@@ -45,7 +43,6 @@ APERTURE_CL = [CircularAperture,
                RectangularAperture,
                RectangularAnnulus]
 
-
 TEST_APERTURES = list(zip(APERTURE_CL, ((3.,), (3., 5.),
                                         (3., 5., 1.), (3., 5., 4., 1.),
                                         (5, 8, np.pi / 4),
@@ -104,7 +101,7 @@ def test_aperture_pixel_positions():
     assert_allclose(pos3_pairs, ap3.positions)
 
 
-class BaseTestAperturePhotometry(object):
+class BaseTestAperturePhotometry:
 
     def test_scalar_error(self):
         # Scalar error
@@ -296,7 +293,7 @@ class TestMaskedSkipCircular(BaseTestAperturePhotometry):
         self.true_flux = self.area - 1
 
 
-class BaseTestDifferentData(object):
+class BaseTestDifferentData:
 
     def test_basic_circular_aperture_photometry(self):
         aperture = CircularAperture(self.position, self.radius)
@@ -361,7 +358,7 @@ class TestInputNDData(BaseTestDifferentData):
         self.fluxunit = u.adu
 
 
-@remote_data
+@pytest.mark.remote_data
 def test_wcs_based_photometry_to_catalogue():
     pathcat = get_path('spitzer_example_catalog.xml', location='remote')
     pathhdu = get_path('spitzer_example_image.fits', location='remote')
@@ -395,6 +392,9 @@ def test_wcs_based_photometry_to_catalogue():
     assert(np.mean(np.fabs(((fluxes_catalog - converted_aperture_sum.value) /
                             fluxes_catalog))) < 0.1)
 
+    # close the file
+    hdu.close()
+
 
 def test_wcs_based_photometry():
     data = make_4gaussians_image()
@@ -509,8 +509,7 @@ def test_basic_circular_aperture_photometry_unit():
 
     table1 = aperture_photometry(data1, CircularAperture(position, radius),
                                  unit=unit)
-    table2 = aperture_photometry(data2, CircularAperture(position, radius),
-                                 unit=unit)
+    table2 = aperture_photometry(data2, CircularAperture(position, radius))
 
     assert_allclose(table1['aperture_sum'].value, true_flux)
     assert_allclose(table2['aperture_sum'].value, true_flux)
@@ -664,64 +663,119 @@ def test_sky_aperture_repr():
     s = SkyCoord([1, 2], [3, 4], unit='deg')
 
     aper = SkyCircularAperture(s, r=3*u.pix)
-    a_repr = ('<SkyCircularAperture(<SkyCoord (ICRS): (ra, dec) in deg\n'
-              '    [( 1.,  3.), ( 2.,  4.)]>, r=3.0 pix)>')
-    a_str = ('Aperture: SkyCircularAperture\npositions: <SkyCoord '
-             '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
-             'r: 3.0 pix')
+    if NUMPY_LT_1_14:
+        a_repr = ('<SkyCircularAperture(<SkyCoord (ICRS): (ra, dec) in deg\n'
+                  '    [( 1.,  3.), ( 2.,  4.)]>, r=3.0 pix)>')
+        a_str = ('Aperture: SkyCircularAperture\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
+                 'r: 3.0 pix')
+    else:
+        a_repr = ('<SkyCircularAperture(<SkyCoord (ICRS): (ra, dec) in deg\n'
+                  '    [(1., 3.), (2., 4.)]>, r=3.0 pix)>')
+        a_str = ('Aperture: SkyCircularAperture\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
+                 'r: 3.0 pix')
+
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
     aper = SkyCircularAnnulus(s, r_in=3.*u.pix, r_out=5*u.pix)
-    a_repr = ('<SkyCircularAnnulus(<SkyCoord (ICRS): (ra, dec) in deg\n'
-              '    [( 1.,  3.), ( 2.,  4.)]>, r_in=3.0 pix, r_out=5.0 pix)>')
-    a_str = ('Aperture: SkyCircularAnnulus\npositions: <SkyCoord '
-             '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
-             'r_in: 3.0 pix\nr_out: 5.0 pix')
+    if NUMPY_LT_1_14:
+        a_repr = ('<SkyCircularAnnulus(<SkyCoord (ICRS): (ra, dec) in deg\n'
+                  '    [( 1.,  3.), ( 2.,  4.)]>, r_in=3.0 pix, '
+                  'r_out=5.0 pix)>')
+        a_str = ('Aperture: SkyCircularAnnulus\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
+                 'r_in: 3.0 pix\nr_out: 5.0 pix')
+    else:
+        a_repr = ('<SkyCircularAnnulus(<SkyCoord (ICRS): (ra, dec) in deg\n'
+                  '    [(1., 3.), (2., 4.)]>, r_in=3.0 pix, r_out=5.0 pix)>')
+        a_str = ('Aperture: SkyCircularAnnulus\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
+                 'r_in: 3.0 pix\nr_out: 5.0 pix')
+
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
     aper = SkyEllipticalAperture(s, a=3*u.pix, b=5*u.pix, theta=15*u.deg)
-    a_repr = ('<SkyEllipticalAperture(<SkyCoord (ICRS): (ra, dec) in '
-              'deg\n    [( 1.,  3.), ( 2.,  4.)]>, a=3.0 pix, b=5.0 pix,'
-              ' theta=15.0 deg)>')
-    a_str = ('Aperture: SkyEllipticalAperture\npositions: <SkyCoord '
-             '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
-             'a: 3.0 pix\nb: 5.0 pix\ntheta: 15.0 deg')
+    if NUMPY_LT_1_14:
+        a_repr = ('<SkyEllipticalAperture(<SkyCoord (ICRS): (ra, dec) in '
+                  'deg\n    [( 1.,  3.), ( 2.,  4.)]>, a=3.0 pix, b=5.0 pix,'
+                  ' theta=15.0 deg)>')
+        a_str = ('Aperture: SkyEllipticalAperture\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
+                 'a: 3.0 pix\nb: 5.0 pix\ntheta: 15.0 deg')
+    else:
+        a_repr = ('<SkyEllipticalAperture(<SkyCoord (ICRS): (ra, dec) in '
+                  'deg\n    [(1., 3.), (2., 4.)]>, a=3.0 pix, b=5.0 pix,'
+                  ' theta=15.0 deg)>')
+        a_str = ('Aperture: SkyEllipticalAperture\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
+                 'a: 3.0 pix\nb: 5.0 pix\ntheta: 15.0 deg')
+
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
     aper = SkyEllipticalAnnulus(s, a_in=3*u.pix, a_out=5*u.pix, b_out=3*u.pix,
                                 theta=15*u.deg)
-    a_repr = ('<SkyEllipticalAnnulus(<SkyCoord (ICRS): (ra, dec) in '
-              'deg\n    [( 1.,  3.), ( 2.,  4.)]>, a_in=3.0 pix, '
-              'a_out=5.0 pix, b_out=3.0 pix, theta=15.0 deg)>')
-    a_str = ('Aperture: SkyEllipticalAnnulus\npositions: <SkyCoord '
-             '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
-             'a_in: 3.0 pix\na_out: 5.0 pix\nb_out: 3.0 pix\n'
-             'theta: 15.0 deg')
+    if NUMPY_LT_1_14:
+        a_repr = ('<SkyEllipticalAnnulus(<SkyCoord (ICRS): (ra, dec) in '
+                  'deg\n    [( 1.,  3.), ( 2.,  4.)]>, a_in=3.0 pix, '
+                  'a_out=5.0 pix, b_out=3.0 pix, theta=15.0 deg)>')
+        a_str = ('Aperture: SkyEllipticalAnnulus\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
+                 'a_in: 3.0 pix\na_out: 5.0 pix\nb_out: 3.0 pix\n'
+                 'theta: 15.0 deg')
+    else:
+        a_repr = ('<SkyEllipticalAnnulus(<SkyCoord (ICRS): (ra, dec) in '
+                  'deg\n    [(1., 3.), (2., 4.)]>, a_in=3.0 pix, '
+                  'a_out=5.0 pix, b_out=3.0 pix, theta=15.0 deg)>')
+        a_str = ('Aperture: SkyEllipticalAnnulus\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
+                 'a_in: 3.0 pix\na_out: 5.0 pix\nb_out: 3.0 pix\n'
+                 'theta: 15.0 deg')
+
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
     aper = SkyRectangularAperture(s, w=3*u.pix, h=5*u.pix, theta=15*u.deg)
-    a_repr = ('<SkyRectangularAperture(<SkyCoord (ICRS): (ra, dec) in '
-              'deg\n    [( 1.,  3.), ( 2.,  4.)]>, w=3.0 pix, h=5.0 pix'
-              ', theta=15.0 deg)>')
-    a_str = ('Aperture: SkyRectangularAperture\npositions: <SkyCoord '
-             '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
-             'w: 3.0 pix\nh: 5.0 pix\ntheta: 15.0 deg')
+    if NUMPY_LT_1_14:
+        a_repr = ('<SkyRectangularAperture(<SkyCoord (ICRS): (ra, dec) in '
+                  'deg\n    [( 1.,  3.), ( 2.,  4.)]>, w=3.0 pix, h=5.0 pix'
+                  ', theta=15.0 deg)>')
+        a_str = ('Aperture: SkyRectangularAperture\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
+                 'w: 3.0 pix\nh: 5.0 pix\ntheta: 15.0 deg')
+    else:
+        a_repr = ('<SkyRectangularAperture(<SkyCoord (ICRS): (ra, dec) in '
+                  'deg\n    [(1., 3.), (2., 4.)]>, w=3.0 pix, h=5.0 pix'
+                  ', theta=15.0 deg)>')
+        a_str = ('Aperture: SkyRectangularAperture\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
+                 'w: 3.0 pix\nh: 5.0 pix\ntheta: 15.0 deg')
+
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
     aper = SkyRectangularAnnulus(s, w_in=3*u.pix, w_out=3.4*u.pix,
                                  h_out=5*u.pix, theta=15*u.deg)
-    a_repr = ('<SkyRectangularAnnulus(<SkyCoord (ICRS): (ra, dec) in deg'
-              '\n    [( 1.,  3.), ( 2.,  4.)]>, w_in=3.0 pix, '
-              'w_out=3.4 pix, h_out=5.0 pix, theta=15.0 deg)>')
-    a_str = ('Aperture: SkyRectangularAnnulus\npositions: <SkyCoord '
-             '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
-             'w_in: 3.0 pix\nw_out: 3.4 pix\nh_out: 5.0 pix\n'
-             'theta: 15.0 deg')
+    if NUMPY_LT_1_14:
+        a_repr = ('<SkyRectangularAnnulus(<SkyCoord (ICRS): (ra, dec) in deg'
+                  '\n    [( 1.,  3.), ( 2.,  4.)]>, w_in=3.0 pix, '
+                  'w_out=3.4 pix, h_out=5.0 pix, theta=15.0 deg)>')
+        a_str = ('Aperture: SkyRectangularAnnulus\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [( 1.,  3.), ( 2.,  4.)]>\n'
+                 'w_in: 3.0 pix\nw_out: 3.4 pix\nh_out: 5.0 pix\n'
+                 'theta: 15.0 deg')
+    else:
+        a_repr = ('<SkyRectangularAnnulus(<SkyCoord (ICRS): (ra, dec) in deg'
+                  '\n    [(1., 3.), (2., 4.)]>, w_in=3.0 pix, '
+                  'w_out=3.4 pix, h_out=5.0 pix, theta=15.0 deg)>')
+        a_str = ('Aperture: SkyRectangularAnnulus\npositions: <SkyCoord '
+                 '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
+                 'w_in: 3.0 pix\nw_out: 3.4 pix\nh_out: 5.0 pix\n'
+                 'theta: 15.0 deg')
+
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
@@ -828,3 +882,44 @@ def test_to_sky_pixel():
     assert_allclose(ap.w_out, ap2.w_out)
     assert_allclose(ap.h_out, ap2.h_out)
     assert_allclose(ap.theta, ap2.theta)
+
+
+def test_position_units():
+    """Regression test for unit check."""
+    pos = (10, 10) * u.pix
+    pos = np.sqrt(pos**2)
+    ap = CircularAperture(pos, r=3.)
+    assert_allclose(ap.positions, np.array([[10, 10]]))
+
+
+def test_radius_units():
+    """Regression test for unit check."""
+    pos = SkyCoord(10, 10, unit='deg')
+    r = 3.*u.pix
+    r = np.sqrt(r**2)
+    ap = SkyCircularAperture(pos, r=r)
+    assert ap.r.value == 3.0
+    assert ap.r.unit == u.pix
+
+
+def test_scalar_aperture():
+    """
+    Regression test to check that length-1 aperture list appends a "_0"
+    on the column names to be consistent with list inputs.
+    """
+
+    data = np.ones((20, 20), dtype=np.float)
+
+    ap = CircularAperture((10, 10), r=3.)
+    colnames1 = aperture_photometry(data, ap, error=data).colnames
+    assert (colnames1 == ['id', 'xcenter', 'ycenter', 'aperture_sum',
+                          'aperture_sum_err'])
+
+    colnames2 = aperture_photometry(data, [ap], error=data).colnames
+    assert (colnames2 == ['id', 'xcenter', 'ycenter', 'aperture_sum_0',
+                          'aperture_sum_err_0'])
+
+    colnames3 = aperture_photometry(data, [ap, ap], error=data).colnames
+    assert (colnames3 == ['id', 'xcenter', 'ycenter', 'aperture_sum_0',
+                          'aperture_sum_err_0', 'aperture_sum_1',
+                          'aperture_sum_err_1'])
