@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+
 import itertools
 
 import numpy as np
@@ -11,11 +10,13 @@ import pytest
 from ..core import (centroid_com, centroid_1dg, centroid_2dg,
                     gaussian1d_moments, fit_2dgaussian)
 
+
 try:
-    import skimage    # noqa
-    HAS_SKIMAGE = True
+    # the fitting routines in astropy use scipy.optimize
+    import scipy    # noqa
+    HAS_SCIPY = True
 except ImportError:
-    HAS_SKIMAGE = False
+    HAS_SCIPY = False
 
 
 XCS = [25.7]
@@ -29,10 +30,10 @@ DATA[1, 0:2] = 1.
 DATA[1, 1] = 2.
 
 
+@pytest.mark.skipif('not HAS_SCIPY')
 @pytest.mark.parametrize(
     ('xc_ref', 'yc_ref', 'x_stddev', 'y_stddev', 'theta'),
     list(itertools.product(XCS, YCS, XSTDDEVS, YSTDDEVS, THETAS)))
-@pytest.mark.skipif('not HAS_SKIMAGE')
 def test_centroids(xc_ref, yc_ref, x_stddev, y_stddev, theta):
     model = Gaussian2D(2.4, xc_ref, yc_ref, x_stddev=x_stddev,
                        y_stddev=y_stddev, theta=theta)
@@ -49,10 +50,10 @@ def test_centroids(xc_ref, yc_ref, x_stddev, y_stddev, theta):
     assert_allclose([xc_ref, yc_ref], [xc3, yc3], rtol=0, atol=1.e-3)
 
 
+@pytest.mark.skipif('not HAS_SCIPY')
 @pytest.mark.parametrize(
     ('xc_ref', 'yc_ref', 'x_stddev', 'y_stddev', 'theta'),
     list(itertools.product(XCS, YCS, XSTDDEVS, YSTDDEVS, THETAS)))
-@pytest.mark.skipif('not HAS_SKIMAGE')
 def test_centroids_witherror(xc_ref, yc_ref, x_stddev, y_stddev, theta):
     model = Gaussian2D(2.4, xc_ref, yc_ref, x_stddev=x_stddev,
                        y_stddev=y_stddev, theta=theta)
@@ -67,7 +68,7 @@ def test_centroids_witherror(xc_ref, yc_ref, x_stddev, y_stddev, theta):
     assert_allclose([xc_ref, yc_ref], [xc3, yc3], rtol=0, atol=1.e-3)
 
 
-@pytest.mark.skipif('not HAS_SKIMAGE')
+@pytest.mark.skipif('not HAS_SCIPY')
 def test_centroids_withmask():
     xc_ref, yc_ref = 24.7, 25.2
     model = Gaussian2D(2.4, xc_ref, yc_ref, x_stddev=5.0, y_stddev=5.0)
@@ -87,7 +88,19 @@ def test_centroids_withmask():
     assert_allclose([xc3, yc3], [xc_ref, yc_ref], rtol=0, atol=1.e-3)
 
 
-@pytest.mark.skipif('not HAS_SKIMAGE')
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_centroids_withmask_nonbool():
+    data = np.arange(16).reshape(4, 4)
+    mask = np.zeros(data.shape)
+    mask[0:2, :] = 1
+    mask2 = np.array(mask, dtype=bool)
+
+    xc1, yc1 = centroid_com(data, mask=mask)
+    xc2, yc2 = centroid_com(data, mask=mask2)
+    assert_allclose([xc1, yc1], [xc2, yc2])
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
 @pytest.mark.parametrize('use_mask', [True, False])
 def test_centroids_nan_withmask(use_mask):
     xc_ref, yc_ref = 24.7, 25.2
@@ -112,7 +125,6 @@ def test_centroids_nan_withmask(use_mask):
     assert_allclose([xc3, yc3], [xc_ref, yc_ref], rtol=0, atol=1.e-3)
 
 
-@pytest.mark.skipif('not HAS_SKIMAGE')
 def test_centroid_com_mask():
     """Test centroid_com with and without an image_mask."""
 
@@ -124,7 +136,7 @@ def test_centroid_com_mask():
     assert_allclose([0.5, 0.0], centroid_mask, rtol=0, atol=1.e-6)
 
 
-@pytest.mark.skipif('not HAS_SKIMAGE')
+@pytest.mark.skipif('not HAS_SCIPY')
 def test_invalid_mask_shape():
     """
     Test if ValueError raises if mask shape doesn't match data
@@ -147,7 +159,7 @@ def test_invalid_mask_shape():
         gaussian1d_moments(data, mask=mask)
 
 
-@pytest.mark.skipif('not HAS_SKIMAGE')
+@pytest.mark.skipif('not HAS_SCIPY')
 def test_invalid_error_shape():
     """
     Test if ValueError raises if error shape doesn't match data
@@ -183,6 +195,7 @@ def test_gaussian1d_moments():
     assert_allclose(result, desired, rtol=0, atol=1.e-6)
 
 
+@pytest.mark.skipif('not HAS_SCIPY')
 def test_fit2dgaussian_dof():
     data = np.ones((2, 2))
     with pytest.raises(ValueError):
