@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+
 import warnings
 
 import numpy as np
@@ -18,7 +17,7 @@ from .sample import EllipseSample, CentralEllipseSample
 __all__ = ['Ellipse']
 
 
-class Ellipse(object):
+class Ellipse:
     """
     Class to fit elliptical isophotes to a galaxy image.
 
@@ -180,8 +179,8 @@ class Ellipse(object):
         if geometry is not None:
             self._geometry = geometry
         else:
-            _x0 = image.shape[0] / 2
-            _y0 = image.shape[1] / 2
+            _x0 = image.shape[1] / 2
+            _y0 = image.shape[0] / 2
             self._geometry = EllipseGeometry(_x0, _y0, 10., eps=0.2,
                                              pa=np.pi/2)
 
