@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+
 import copy
 
 import numpy as np
@@ -12,7 +11,7 @@ from .integrator import integrators
 __all__ = ['EllipseSample']
 
 
-class EllipseSample(object):
+class EllipseSample:
     """
     Class to sample image data along an elliptical path.
 
@@ -106,8 +105,8 @@ class EllipseSample(object):
             _x0 = x0
             _y0 = y0
             if not _x0 or not _y0:
-                _x0 = image.shape[0] / 2
-                _y0 = image.shape[1] / 2
+                _x0 = image.shape[1] / 2
+                _y0 = image.shape[0] / 2
 
             self.geometry = EllipseGeometry(_x0, _y0, sma, eps,
                                             position_angle, astep,
