@@ -5,7 +5,6 @@ from numpy.testing import assert_allclose
 import pytest
 
 from astropy.io import fits
-from astropy.tests.helper import remote_data
 
 from .make_test_data import make_test_image
 from ..fitter import EllipseFitter, CentralEllipseFitter
@@ -159,7 +158,7 @@ def test_fitting_all():
     assert isophote_m.stop_code == 0
 
 
-@remote_data
+@pytest.mark.remote_data
 @pytest.mark.skipif('not HAS_SCIPY')
 class TestM51:
     def setup_class(self):
