@@ -3,16 +3,16 @@
 import numpy as np
 import numpy.ma as ma
 from numpy.testing import assert_allclose
+import pytest
 
 from astropy.io import fits
-from astropy.tests.helper import remote_data
 
 from ..sample import EllipseSample
 from ..integrator import NEAREST_NEIGHBOR, BILINEAR, MEAN, MEDIAN
 from ...datasets import get_path
 
 
-@remote_data
+@pytest.mark.remote_data
 class TestData:
     def setup_class(self):
         path = get_path('isophote/synth_highsnr.fits',
@@ -36,7 +36,7 @@ class TestData:
         return s, sample
 
 
-@remote_data
+@pytest.mark.remote_data
 class TestUnmasked(TestData):
     def test_bilinear(self):
         s, sample = self.make_sample()
@@ -126,7 +126,7 @@ class TestUnmasked(TestData):
         assert sample.actual_points == 64
 
 
-@remote_data
+@pytest.mark.remote_data
 class TestMasked(TestData):
     def test_bilinear(self):
         s, sample = self.make_sample(masked=True, integrmode=BILINEAR)
