@@ -4,13 +4,8 @@ Functions for measuring morphological properties of objects in an
 astronomical image using image moments.
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 import numpy as np
 
-from ..segmentation import SourceProperties
-
 
 __all__ = ['data_properties']
 
@@ -45,6 +40,8 @@ def data_properties(data, mask=None, background=None):
         A `~photutils.segmentation.SourceProperties` object.
     """
 
+    from ..segmentation import SourceProperties  # prevent circular imports
+
     segment_image = np.ones(data.shape, dtype=np.int)
 
     return SourceProperties(data, segment_image, label=1, mask=mask,
