@@ -6,9 +6,8 @@ photometry.
 
 from .epsf import *          # noqa
 from .epsf_stars import *    # noqa
-from .funcs import *         # noqa
 from .groupstars import *    # noqa
 from .matching import *      # noqa
 from .models import *        # noqa
-from .groupstars import *    # noqa
 from .photometry import *    # noqa
+from .utils import *         # noqa
