@@ -5,7 +5,6 @@ King (2000; PASP 112, 1360).
 """
 
 import copy
-import sys
 import time
 import warnings
 
@@ -13,9 +12,10 @@ import numpy as np
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.nddata.utils import (overlap_slices, PartialOverlapError,
                                   NoOverlapError)
-from astropy.utils.exceptions import AstropyUserWarning
+from astropy.utils.exceptions import (AstropyUserWarning,
+                                      AstropyDeprecationWarning)
 
-from .epsf_stars import Star, LinkedStar, Stars
+from .epsf_stars import EPSFStar, LinkedEPSFStar, EPSFStars
 from .models import EPSFModel
 from ..centroids import centroid_com
 from ..extern import SigmaClip
@@ -92,7 +92,7 @@ class EPSFFitter:
         epsf : `EPSFModel`
             An ePSF model to be fitted to the stars.
 
-        stars : `Stars` object
+        stars : `EPSFStars` object
             The stars to be fit.  The center coordinates for each star
             should be as close as possible to actual centers.  For stars
             than contain weights, a weighted fit of the ePSF to the star
@@ -100,7 +100,7 @@ class EPSFFitter:
 
         Returns
         -------
-        fitted_stars : `Stars` object
+        fitted_stars : `EPSFStars` object
             The fitted stars.  The ePSF-fitted center position and flux
             are stored in the ``center`` (and ``cutout_center``) and
             ``flux`` attributes.
@@ -118,13 +118,13 @@ class EPSFFitter:
         # perform the fit
         fitted_stars = []
         for star in stars:
-            if isinstance(star, Star):
+            if isinstance(star, EPSFStar):
                 fitted_star = self._fit_star(epsf, star, self.fitter,
                                              self.fitter_kwargs,
                                              self.fitter_has_fit_info,
                                              self.fit_boxsize)
 
-            elif isinstance(star, LinkedStar):
+            elif isinstance(star, LinkedEPSFStar):
                 fitted_star = []
                 for linked_star in star:
                     fitted_star.append(
@@ -133,16 +133,16 @@ class EPSFFitter:
                                        self.fitter_has_fit_info,
                                        self.fit_boxsize))
 
-                fitted_star = LinkedStar(fitted_star)
+                fitted_star = LinkedEPSFStar(fitted_star)
                 fitted_star.constrain_centers()
 
             else:
-                raise TypeError('stars must contain only Star and/or '
-                                'LinkedStar objects.')
+                raise TypeError('stars must contain only EPSFStar and/or '
+                                'LinkedEPSFStar objects.')
 
             fitted_stars.append(fitted_star)
 
-        return Stars(fitted_stars)
+        return EPSFStars(fitted_stars)
 
     def _fit_star(self, epsf, star, fitter, fitter_kwargs,
                   fitter_has_fit_info, fit_boxsize):
@@ -205,7 +205,7 @@ class EPSFFitter:
         # The oversampling factor is used in the FittableImageModel
         # evaluate method (which is use when fitting).  We do not want
         # to use oversampling here because it has been set by the ratio
-        # of the ePSF and Star pixel scales.  This allows for
+        # of the ePSF and EPSFStar pixel scales.  This allows for
         # oversampling factors that differ between stars and also for
         # the factor to be different along the x and y axes.
         epsf._oversampling = 1.
@@ -255,6 +255,12 @@ class EPSFBuilder:
     Parameters
     ----------
     pixel_scale : float or tuple of two floats, optional
+        .. warning::
+
+            The ``pixel_scale`` keyword is now deprecated (since v0.6)
+            and will likely be removed in v0.7.  Use the
+            ``oversampling`` keyword instead.
+
         The pixel scale (in arbitrary units) of the output ePSF.  The
         ``pixel_scale`` can either be a single float or tuple of two
         floats of the form ``(x_pixscale, y_pixscale)``.  If
@@ -288,17 +294,17 @@ class EPSFBuilder:
 
     smoothing_kernel : {'quartic', 'quadratic'}, 2D `~numpy.ndarray`, or `None`
         The smoothing kernel to apply to the ePSF.  The predefined
-        kernels ``'quartic'`` and ``'quadratic'`` have been optimized
-        for ePSF oversampling factors close to 4.  Alternatively, a
-        custom 2D array can be input.  If `None` then no smoothing will
-        be performed.  The default is ``'quartic'``.
+        ``'quartic'`` and ``'quadratic'`` kernels are derived from
+        fourth and second degree polynomials, respectively.
+        Alternatively, a custom 2D array can be input.  If `None` then
+        no smoothing will be performed.  The default is ``'quartic'``.
 
     recentering_func : callable, optional
         A callable object (e.g. function or class) that is used to
         calculate the centroid of a 2D array.  The callable must accept
         a 2D `~numpy.ndarray`, have a ``mask`` keyword and optionally an
         ``error`` keyword.  The callable object must return a tuple of
-        two 1D `~numpy.ndarray`\s, representing the x and y centroids.
+        two 1D `~numpy.ndarray`\\s, representing the x and y centroids.
         The default is `~photutils.centroids.centroid_com`.
 
     recentering_boxsize : float or tuple of two floats, optional
@@ -345,6 +351,11 @@ class EPSFBuilder:
             raise ValueError('Either pixel_scale or oversampling must be '
                              'input.')
 
+        if pixel_scale is not None:
+            warnings.warn('The pixel_scale keyword is deprecated and will '
+                          'likely be removed in v0.7.  Use the oversampling '
+                          'keyword instead.', AstropyDeprecationWarning)
+
         self.pixel_scale = self._init_img_params(pixel_scale)
         if oversampling <= 0.0:
             raise ValueError('oversampling must be a positive number.')
@@ -359,6 +370,9 @@ class EPSFBuilder:
         self.recentering_maxiters = recentering_maxiters
 
         self.smoothing_kernel = smoothing_kernel
+
+        if not isinstance(fitter, EPSFFitter):
+            raise TypeError('fitter must be an EPSFFitter instance.')
         self.fitter = fitter
 
         if center_accuracy <= 0.0:
@@ -418,7 +432,7 @@ class EPSFBuilder:
 
         Parameters
         ----------
-        stars : `Stars` object
+        stars : `EPSFStars` object
             The stars used to build the ePSF.
 
         Returns
@@ -473,9 +487,11 @@ class EPSFBuilder:
         # FittableImageModel requires a scalar oversampling factor
         oversampling = np.mean(oversampling)
 
-        return EPSFModel(data=data, origin=(xcenter, ycenter),
-                         normalize=False, oversampling=oversampling,
-                         pixel_scale=pixel_scale)
+        epsf = EPSFModel(data=data, origin=(xcenter, ycenter),
+                         normalize=False, oversampling=oversampling)
+        epsf._pixel_scale = pixel_scale
+
+        return epsf
 
     def _resample_residual(self, star, epsf):
         """
@@ -490,7 +506,7 @@ class EPSFBuilder:
 
         Parameters
         ----------
-        star : `Star` object
+        star : `EPSFStar` object
             A single star object.
 
         epsf : `EPSFModel` object
@@ -503,7 +519,7 @@ class EPSFBuilder:
             image contains NaNs where there is no data.
         """
 
-        # find the integer index of Star pixels in the oversampled
+        # find the integer index of EPSFStar pixels in the oversampled
         # ePSF grid
         x_oversamp = star.pixel_scale[0] / epsf.pixel_scale[0]
         y_oversamp = star.pixel_scale[1] / epsf.pixel_scale[1]
@@ -540,7 +556,7 @@ class EPSFBuilder:
 
         Parameters
         ----------
-        stars : `Stars` object
+        stars : `EPSFStars` object
             The stars used to build the ePSF.
 
         epsf : `EPSFModel` object
@@ -640,7 +656,7 @@ class EPSFBuilder:
             calculate the centroid of a 2D array.  The callable must
             accept a 2D `~numpy.ndarray`, have a ``mask`` keyword and
             optionally an ``error`` keyword.  The callable object must
-            return a tuple of two 1D `~numpy.ndarray`\s, representing
+            return a tuple of two 1D `~numpy.ndarray`\\s, representing
             the x and y centroids.  The default is
             `~photutils.centroids.centroid_com`.
 
@@ -670,9 +686,11 @@ class EPSFBuilder:
         # Define an EPSFModel for the input data.  This EPSFModel will be
         # used to evaluate the model on a shifted pixel grid to place the
         # centroid at the array center.
+        pixel_scale = epsf.pixel_scale
         epsf = EPSFModel(data=epsf_data, origin=epsf.origin, normalize=False,
-                         oversampling=epsf.oversampling,
-                         pixel_scale=epsf.pixel_scale)
+                         oversampling=epsf.oversampling)
+        epsf._pixel_scale = pixel_scale
+
         epsf.fill_value = 0.0
         xcenter, ycenter = epsf.origin
 
@@ -727,7 +745,7 @@ class EPSFBuilder:
 
         Parameters
         ----------
-        stars : `Stars` object
+        stars : `EPSFStars` object
             The stars used to build the ePSF.
 
         epsf : `EPSFModel` object, optional
@@ -741,8 +759,8 @@ class EPSFBuilder:
         """
 
         if len(stars) < 1:
-            raise ValueError('stars must contain at least one Star or '
-                             'LinkedStar object.')
+            raise ValueError('stars must contain at least one EPSFStar or '
+                             'LinkedEPSFStar object.')
 
         if epsf is None:
             # create an initial ePSF (array of zeros)
@@ -800,9 +818,11 @@ class EPSFBuilder:
         xcenter = (new_epsf.shape[1] - 1) / 2.
         ycenter = (new_epsf.shape[0] - 1) / 2.
 
-        return EPSFModel(data=new_epsf, origin=(xcenter, ycenter),
-                         normalize=False, oversampling=epsf.oversampling,
-                         pixel_scale=epsf.pixel_scale)
+        epsf_new = EPSFModel(data=new_epsf, origin=(xcenter, ycenter),
+                             normalize=False, oversampling=epsf.oversampling)
+        epsf_new._pixel_scale = epsf.pixel_scale
+
+        return epsf_new
 
     def build_epsf(self, stars, init_epsf=None):
         """
@@ -810,7 +830,7 @@ class EPSFBuilder:
 
         Parameters
         ----------
-        stars : `Stars` object
+        stars : `EPSFStars` object
             The stars used to build the ePSF.
 
         init_epsf : `EPSFModel` object, optional
@@ -822,7 +842,7 @@ class EPSFBuilder:
         epsf : `EPSFModel` object
             The constructed ePSF.
 
-        fitted_stars : `Stars` object
+        fitted_stars : `EPSFStars` object
             The input stars with updated centers and fluxes derived
             from fitting the output ``epsf``.
         """
