@@ -1,7 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Module which provides classes to perform PSF Photometry"""
 
-from __future__ import division
 import numpy as np
 import warnings
 
@@ -9,12 +8,11 @@ from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.nddata.utils import overlap_slices
 from astropy.stats import gaussian_sigma_to_fwhm, SigmaClip
 from astropy.table import Table, Column, vstack, hstack
-from astropy.utils import deprecated_renamed_argument
 from astropy.utils.exceptions import AstropyUserWarning
 
-from . import DAOGroup
-from .funcs import subtract_psf, _extract_psf_fitting_names
-from .models import get_grouped_psf_model
+from .groupstars import DAOGroup
+from .utils import (get_grouped_psf_model, subtract_psf,
+                    _extract_psf_fitting_names)
 from ..aperture import CircularAperture, aperture_photometry
 from ..background import MMMBackground
 from ..detection import DAOStarFinder
@@ -24,7 +22,7 @@ __all__ = ['BasicPSFPhotometry', 'IterativelySubtractedPSFPhotometry',
            'DAOPhotPSFPhotometry']
 
 
-class BasicPSFPhotometry(object):
+class BasicPSFPhotometry:
     """
     This class implements a PSF photometry algorithm that can find
     sources in an image, group overlapping sources into a single model,
@@ -91,7 +89,7 @@ class BasicPSFPhotometry(object):
     aperture_radius : float or None
         The radius (in units of pixels) used to compute initial
         estimates for the fluxes of sources. If ``None``, one FWHM will
-        be used if it can be determined from the ```psf_model``.
+        be used if it can be determined from the ``psf_model``.
 
     Notes
     -----
@@ -180,7 +178,6 @@ class BasicPSFPhotometry(object):
 
         return self._residual_image
 
-    @deprecated_renamed_argument('positions', 'init_guesses', '0.4')
     def __call__(self, image, init_guesses=None):
         """
         Performs PSF photometry. See `do_photometry` for more details
@@ -189,7 +186,6 @@ class BasicPSFPhotometry(object):
 
         return self.do_photometry(image, init_guesses)
 
-    @deprecated_renamed_argument('positions', 'init_guesses', '0.4')
     def do_photometry(self, image, init_guesses=None):
         """
         Perform PSF photometry in ``image``.
@@ -564,9 +560,8 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
                  finder, fitter=LevMarLSQFitter(), niters=3,
                  aperture_radius=None):
 
-        super(IterativelySubtractedPSFPhotometry, self).__init__(
-            group_maker, bkg_estimator, psf_model, fitshape, finder, fitter,
-            aperture_radius)
+        super().__init__(group_maker, bkg_estimator, psf_model, fitshape,
+                         finder, fitter, aperture_radius)
         self.niters = niters
 
     @property
@@ -601,7 +596,6 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
         else:
             self._finder = value
 
-    @deprecated_renamed_argument('positions', 'init_guesses', '0.4')
     def do_photometry(self, image, init_guesses=None):
         """
         Perform PSF photometry in ``image``.
@@ -645,8 +639,7 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
         """
 
         if init_guesses is not None:
-            table = super(IterativelySubtractedPSFPhotometry,
-                          self).do_photometry(image, init_guesses)
+            table = super().do_photometry(image, init_guesses)
             table['iter_detected'] = np.ones(table['x_fit'].shape,
                                              dtype=np.int32)
 
@@ -725,9 +718,8 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
                                      np.ones(len(sources)))))
 
             star_groups = self.group_maker(init_guess_tab)
-            table, self._residual_image = super(
-                IterativelySubtractedPSFPhotometry, self).nstar(
-                    self._residual_image, star_groups)
+            table, self._residual_image = super().nstar(
+                self._residual_image, star_groups)
 
             star_groups = star_groups.group_by('group_id')
             table = hstack([star_groups, table])
@@ -879,7 +871,7 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
                                sharplo=self.sharplo, sharphi=self.sharphi,
                                roundlo=self.roundlo, roundhi=self.roundhi)
 
-        super(DAOPhotPSFPhotometry, self).__init__(
-            group_maker=group_maker, bkg_estimator=bkg_estimator,
-            psf_model=psf_model, fitshape=fitshape, finder=finder,
-            fitter=fitter, niters=niters, aperture_radius=aperture_radius)
+        super().__init__(group_maker=group_maker, bkg_estimator=bkg_estimator,
+                         psf_model=psf_model, fitshape=fitshape,
+                         finder=finder, fitter=fitter, niters=niters,
+                         aperture_radius=aperture_radius)
