@@ -1,6 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 
 import numpy as np
 from astropy.stats import gaussian_fwhm_to_sigma
@@ -15,7 +13,7 @@ __all__ = ['detect_sources', 'make_source_mask']
 
 
 def detect_sources(data, threshold, npixels, filter_kernel=None,
-                   connectivity=8):
+                   connectivity=8, mask=None):
     """
     Detect sources above a specified threshold value in an image and
     return a `~photutils.segmentation.SegmentationImage` object.
@@ -23,6 +21,8 @@ def detect_sources(data, threshold, npixels, filter_kernel=None,
     Detected sources must have ``npixels`` connected pixels that are
     each greater than the ``threshold`` value.  If the filtering option
     is used, then the ``threshold`` is applied to the filtered image.
+    The input ``mask`` can be used to mask pixels in the input data.
+    Masked pixels will not be included in any source.
 
     This function does not deblend overlapping sources.  First use this
     function to detect sources followed by
@@ -57,6 +57,11 @@ def detect_sources(data, threshold, npixels, filter_kernel=None,
         8-connected pixels touch along their edges or corners.  For
         reference, SExtractor uses 8-connected pixels.
 
+    mask : array_like (bool)
+        A boolean mask, with the same shape as the input ``data``, where
+        `True` values indicate masked pixels.  Masked pixels will not be
+        included in any source.
+
     Returns
     -------
     segment_image : `~photutils.segmentation.SegmentationImage`
@@ -122,6 +127,12 @@ def detect_sources(data, threshold, npixels, filter_kernel=None,
     image = (filter_data(data, filter_kernel, mode='constant', fill_value=0.0,
                          check_normalization=True) > threshold)
 
+    if mask is not None:
+        if mask.shape != image.shape:
+            raise ValueError('mask must have the same shape as the input '
+                             'image.')
+        image &= ~mask
+
     if connectivity == 4:
         selem = ndimage.generate_binary_structure(2, 1)
     elif connectivity == 8:
@@ -130,20 +141,22 @@ def detect_sources(data, threshold, npixels, filter_kernel=None,
         raise ValueError('Invalid connectivity={0}.  '
                          'Options are 4 or 8'.format(connectivity))
 
-    objlabels, nobj = ndimage.label(image, structure=selem)
-    objslices = ndimage.find_objects(objlabels)
+    segm_img, nobj = ndimage.label(image, structure=selem)
 
     # remove objects with less than npixels
-    for objslice in objslices:
-        objlabel = objlabels[objslice]
-        obj_npix = len(np.where(objlabel.ravel() != 0)[0])
-        if obj_npix < npixels:
-            objlabels[objslice] = 0
+    # NOTE:  for typical data, making the cutout images is ~10x faster
+    # than using segm_img directly
+    segm_slices = ndimage.find_objects(segm_img)
+    for i, slices in enumerate(segm_slices):
+        cutout = segm_img[slices]
+        segment_mask = (cutout == (i+1))
+        if np.count_nonzero(segment_mask) < npixels:
+            cutout[segment_mask] = 0
 
-    # relabel to make sequential label indices
-    objlabels, nobj = ndimage.label(objlabels, structure=selem)
+    # now relabel to make consecutive label indices
+    segm_img, nobj = ndimage.label(segm_img, structure=selem)
 
-    return SegmentationImage(objlabels)
+    return SegmentationImage(segm_img)
 
 
 def make_source_mask(data, snr, npixels, mask=None, mask_value=None,
