@@ -1,30 +1,30 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+
 import warnings
 
 import numpy as np
 import astropy.units as u
 from astropy.coordinates import SkyCoord
 from astropy.table import QTable
-from astropy.utils import deprecated, lazyproperty
-from astropy.utils.exceptions import AstropyDeprecationWarning
+from astropy.utils import lazyproperty
+from astropy.utils.exceptions import AstropyUserWarning
 from astropy.wcs.utils import pixel_to_skycoord
 
 
 from .core import SegmentationImage
 from ..utils.convolution import filter_data
+from ..utils._moments import _moments, _moments_central
 
 
-__all__ = ['SourceProperties', 'source_properties', 'SourceCatalog',
-           'properties_table']
+__all__ = ['SourceProperties', 'source_properties', 'SourceCatalog']
 
 __doctest_requires__ = {('SourceProperties', 'SourceProperties.*',
-                         'SourceCatalog', 'SourceCatalog.*', 'source_properties',
-                         'properties_table'): ['scipy', 'skimage']}
+                         'SourceCatalog', 'SourceCatalog.*',
+                         'source_properties', 'properties_table'):
+                        ['scipy', 'skimage']}
 
 
-class SourceProperties(object):
+class SourceProperties:
     """
     Class to calculate photometry and morphological properties of a
     single labeled source.
@@ -167,7 +167,7 @@ class SourceProperties(object):
         self._error = error    # total error; 2D array
         self._background = background    # 2D array
 
-        segment_img.check_label(label)
+        segment_img.check_labels(label)
         self.label = label
         self._slice = segment_img.slices[label - 1]
         self._segment_img = segment_img
@@ -287,7 +287,7 @@ class SourceProperties(object):
         return self.make_cutout(self._data, masked_array=True)
 
     @lazyproperty
-    def _data_cutout_maskzeroed_double(self):
+    def _data_cutout_maskzeroed(self):
         """
         A 2D cutout from the (background-subtracted) (filtered) data,
         where pixels outside of the source segment and masked pixels are
@@ -296,9 +296,7 @@ class SourceProperties(object):
         Invalid values (e.g. NaNs or infs) are set to zero.  Negative
         data values are also set to zero because negative pixels
         (especially at large radii) can result in image moments that
-        result in negative variances.  The cutout image is double
-        precision, which is required for scikit-image's Cython-based
-        moment functions.
+        result in negative variances.
         """
 
         cutout = self.make_cutout(self._filtered_data, masked_array=False)
@@ -354,8 +352,7 @@ class SourceProperties(object):
     def moments(self):
         """Spatial moments up to 3rd order of the source."""
 
-        from skimage.measure import moments
-        return moments(self._data_cutout_maskzeroed_double, 3)
+        return _moments(self._data_cutout_maskzeroed, order=3)
 
     @lazyproperty
     def moments_central(self):
@@ -364,10 +361,9 @@ class SourceProperties(object):
         order.
         """
 
-        from skimage.measure import moments_central
         ycentroid, xcentroid = self.cutout_centroid.value
-        return moments_central(self._data_cutout_maskzeroed_double,
-                               ycentroid, xcentroid, 3)
+        return _moments_central(self._data_cutout_maskzeroed,
+                                center=(xcentroid, ycentroid), order=3)
 
     @lazyproperty
     def id(self):
@@ -387,8 +383,8 @@ class SourceProperties(object):
 
         m = self.moments
         if m[0, 0] != 0:
-            ycentroid = m[0, 1] / m[0, 0]
-            xcentroid = m[1, 0] / m[0, 0]
+            ycentroid = m[1, 0] / m[0, 0]
+            xcentroid = m[0, 1] / m[0, 0]
             return (ycentroid, xcentroid) * u.pix
         else:
             return (np.nan, np.nan) * u.pix
@@ -449,43 +445,6 @@ class SourceProperties(object):
         else:
             return None
 
-    @lazyproperty
-    @deprecated(0.4, alternative='sky_centroid_icrs')
-    def icrs_centroid(self):
-        """
-        The sky coordinates, in the International Celestial Reference
-        System (ICRS) frame, of the centroid within the source segment,
-        returned as a `~astropy.coordinates.SkyCoord` object.
-        """
-
-        return self.sky_centroid_icrs
-
-    @lazyproperty
-    @deprecated(0.4, alternative='sky_centroid_icrs.ra')
-    def ra_icrs_centroid(self):
-        """
-        The ICRS Right Ascension coordinate (in degrees) of the centroid
-        within the source segment.
-        """
-
-        if self._wcs is not None:
-            return self.sky_centroid_icrs.ra.degree * u.deg
-        else:
-            return None
-
-    @lazyproperty
-    @deprecated(0.4, alternative='sky_centroid_icrs.dec')
-    def dec_icrs_centroid(self):
-        """
-        The ICRS Declination coordinate (in degrees) of the centroid
-        within the source segment.
-        """
-
-        if self._wcs is not None:
-            return self.sky_centroid_icrs.dec.degree * u.deg
-        else:
-            return None
-
     @lazyproperty
     def bbox(self):
         """
@@ -612,7 +571,7 @@ class SourceProperties(object):
         within the source segment.
         """
 
-        return np.min(self.values)
+        return np.nanmin(self.values)
 
     @lazyproperty
     def max_value(self):
@@ -621,7 +580,7 @@ class SourceProperties(object):
         within the source segment.
         """
 
-        return np.max(self.values)
+        return np.nanmax(self.values)
 
     @lazyproperty
     def minval_cutout_pos(self):
@@ -630,6 +589,7 @@ class SourceProperties(object):
         minimum pixel value of the (background-subtracted) data.
         """
 
+        # NOTE:  Quantity converts this to float
         return np.argwhere(self.data_cutout_ma == self.min_value)[0] * u.pix
 
     @lazyproperty
@@ -639,6 +599,7 @@ class SourceProperties(object):
         maximum pixel value of the (background-subtracted) data.
         """
 
+        # NOTE:  Quantity converts this to float
         return np.argwhere(self.data_cutout_ma == self.max_value)[0] * u.pix
 
     @lazyproperty
@@ -730,9 +691,9 @@ class SourceProperties(object):
         """
 
         mu = self.moments_central
-        a = mu[2, 0]
+        a = mu[0, 2]
         b = -mu[1, 1]
-        c = mu[0, 2]
+        c = mu[2, 0]
         return np.array([[a, b], [b, c]]) * u.pix**2
 
     @lazyproperty
@@ -746,7 +707,7 @@ class SourceProperties(object):
         if mu[0, 0] != 0:
             m = mu / mu[0, 0]
             covariance = self._check_covariance(
-                np.array([[m[2, 0], m[1, 1]], [m[1, 1], m[0, 2]]]))
+                np.array([[m[0, 2], m[1, 1]], [m[1, 1], m[2, 0]]]))
             return covariance * u.pix**2
         else:
             return np.empty((2, 2)) * np.nan * u.pix**2
@@ -984,8 +945,8 @@ class SourceProperties(object):
         non-masked pixels in the source segment.
         """
 
-        return np.sum(np.ma.masked_array(self._data[self._slice],
-                                         mask=self._cutout_total_mask))
+        return np.nansum(np.ma.masked_array(self._data[self._slice],
+                                            mask=self._cutout_total_mask))
 
     @lazyproperty
     def source_sum_err(self):
@@ -1008,7 +969,7 @@ class SourceProperties(object):
         if self._error is not None:
             # power doesn't work here, see astropy #2968
             # return np.sqrt(np.sum(self.error_cutout_ma**2))
-            return np.sqrt(np.sum(
+            return np.sqrt(np.nansum(
                 np.ma.masked_array(self.error_cutout_ma.data**2,
                                    mask=self.error_cutout_ma.mask)))
         else:
@@ -1048,6 +1009,9 @@ class SourceProperties(object):
             value = map_coordinates(self._background,
                                     [[self.ycentroid.value],
                                      [self.xcentroid.value]])[0]
+
+            # map_coordinates works if self._background is a Quantity, but
+            # the returned value is a numpy array (without units)
             if isinstance(self._background, u.Quantity):
                 value *= self._background.unit
 
@@ -1162,11 +1126,11 @@ def source_properties(data, segment_img, error=None, mask=None,
     >>> import numpy as np
     >>> from photutils import SegmentationImage, source_properties
     >>> image = np.arange(16.).reshape(4, 4)
-    >>> print(image)
-    [[  0.   1.   2.   3.]
-     [  4.   5.   6.   7.]
-     [  8.   9.  10.  11.]
-     [ 12.  13.  14.  15.]]
+    >>> print(image)  # doctest: +SKIP
+    [[ 0.  1.  2.  3.]
+     [ 4.  5.  6.  7.]
+     [ 8.  9. 10. 11.]
+     [12. 13. 14. 15.]]
     >>> segm = SegmentationImage([[1, 1, 0, 0],
     ...                           [1, 0, 0, 2],
     ...                           [0, 0, 2, 2],
@@ -1179,11 +1143,11 @@ def source_properties(data, segment_img, error=None, mask=None,
     >>> props[0].id    # id corresponds to segment label number
     1
     >>> props[0].centroid    # doctest: +FLOAT_CMP
-    <Quantity [ 0.8, 0.2] pix>
+    <Quantity [0.8, 0.2] pix>
     >>> props[0].source_sum    # doctest: +FLOAT_CMP
     5.0
     >>> props[0].area    # doctest: +FLOAT_CMP
-    <Quantity 3.0 pix2>
+    <Quantity 3. pix2>
     >>> props[0].max_value    # doctest: +FLOAT_CMP
     4.0
 
@@ -1193,11 +1157,11 @@ def source_properties(data, segment_img, error=None, mask=None,
     >>> props[1].id    # id corresponds to segment label number
     2
     >>> props[1].centroid    # doctest: +FLOAT_CMP
-    <Quantity [ 2.36363636, 2.09090909] pix>
+    <Quantity [2.36363636, 2.09090909] pix>
     >>> props[1].perimeter    # doctest: +FLOAT_CMP
-    <Quantity 5.414213562373095 pix>
+    <Quantity 5.41421356 pix>
     >>> props[1].orientation    # doctest: +FLOAT_CMP
-    <Quantity -0.7417593069227176 rad>
+    <Quantity -0.74175931 rad>
     """
 
     if not isinstance(segment_img, SegmentationImage):
@@ -1220,7 +1184,10 @@ def source_properties(data, segment_img, error=None, mask=None,
     sources_props = []
     for label in labels:
         if label not in segment_img.labels:
-            continue      # skip invalid labels (without warnings)
+            warnings.warn('label {} is not in the segmentation image.'
+                          .format(label), AstropyUserWarning)
+            continue  # skip invalid labels
+
         sources_props.append(SourceProperties(
             data, segment_img, label, filtered_data=filtered_data,
             error=error, mask=mask, background=background, wcs=wcs))
@@ -1228,7 +1195,7 @@ def source_properties(data, segment_img, error=None, mask=None,
     return SourceCatalog(sources_props, wcs=wcs)
 
 
-class SourceCatalog(object):
+class SourceCatalog:
     """
     Class to hold source catalogs.
     """
@@ -1250,10 +1217,6 @@ class SourceCatalog(object):
     def __getitem__(self, index):
         return self._data[index]
 
-    # python 2 only
-    def __getslice__(self, i, j):
-        return self.__getitem__(slice(i, j))
-
     def __delitem__(self, index):
         del self._data[index]
 
@@ -1302,30 +1265,6 @@ class SourceCatalog(object):
         else:
             return None
 
-    @lazyproperty
-    @deprecated(0.4, alternative='sky_centroid_icrs')
-    def icrs_centroid(self):
-        if self.wcs is not None:
-            return self.sky_centroid_icrs
-        else:
-            return None
-
-    @lazyproperty
-    @deprecated(0.4, alternative='sky_centroid_icrs.ra')
-    def ra_icrs_centroid(self):
-        if self.wcs is not None:
-            return self.sky_centroid_icrs.ra.deg * u.deg
-        else:
-            return None
-
-    @lazyproperty
-    @deprecated(0.4, alternative='sky_centroid_icrs.dec')
-    def dec_icrs_centroid(self):
-        if self.wcs is not None:
-            return self.sky_centroid_icrs.dec.deg * u.deg
-        else:
-            return None
-
     @lazyproperty
     def sky_bbox_ll(self):
         if self.wcs is not None:
@@ -1339,7 +1278,7 @@ class SourceCatalog(object):
     def sky_bbox_ul(self):
         if self.wcs is not None:
             return pixel_to_skycoord(self.xmin.value - 0.5,
-                                     self.ymin.value + 0.5,
+                                     self.ymax.value + 0.5,
                                      self.wcs, origin=0)
         else:
             return None
@@ -1347,7 +1286,7 @@ class SourceCatalog(object):
     @lazyproperty
     def sky_bbox_lr(self):
         if self.wcs is not None:
-            return pixel_to_skycoord(self.xmin.value + 0.5,
+            return pixel_to_skycoord(self.xmax.value + 0.5,
                                      self.ymin.value - 0.5,
                                      self.wcs, origin=0)
         else:
@@ -1356,8 +1295,8 @@ class SourceCatalog(object):
     @lazyproperty
     def sky_bbox_ur(self):
         if self.wcs is not None:
-            return pixel_to_skycoord(self.xmin.value + 0.5,
-                                     self.ymin.value + 0.5,
+            return pixel_to_skycoord(self.xmax.value + 0.5,
+                                     self.ymax.value + 0.5,
                                      self.wcs, origin=0)
         else:
             return None
@@ -1412,11 +1351,11 @@ class SourceCatalog(object):
         >>> import numpy as np
         >>> from photutils import source_properties
         >>> image = np.arange(16.).reshape(4, 4)
-        >>> print(image)
-        [[  0.   1.   2.   3.]
-        [  4.   5.   6.   7.]
-        [  8.   9.  10.  11.]
-        [ 12.  13.  14.  15.]]
+        >>> print(image)  # doctest: +SKIP
+        [[ 0.  1.  2.  3.]
+         [ 4.  5.  6.  7.]
+         [ 8.  9. 10. 11.]
+         [12. 13. 14. 15.]]
         >>> segm = SegmentationImage([[1, 1, 0, 0],
         ...                           [1, 0, 0, 2],
         ...                           [0, 0, 2, 2],
@@ -1483,168 +1422,3 @@ def _properties_table(obj, columns=None, exclude_columns=None):
         tbl[column] = values
 
     return tbl
-
-
-@deprecated(0.4, alternative='SourceCatalog.to_table()')
-def properties_table(source_props, columns=None, exclude_columns=None):
-    """
-    Construct a `~astropy.table.QTable` of properties from a list of
-    `SourceProperties` objects.
-
-    If ``columns`` or ``exclude_columns`` are not input, then the
-    `~astropy.table.QTable` will include most scalar-valued source
-    properties.  Multi-dimensional properties, e.g.
-    `~photutils.SourceProperties.data_cutout`, can be included in the
-    ``columns`` input.
-
-    Parameters
-    ----------
-    source_props : `SourceProperties` or list of `SourceProperties`
-        A `SourceProperties` object or list of `SourceProperties`
-        objects, one for each source.
-
-    columns : str or list of str, optional
-        Names of columns, in order, to include in the output
-        `~astropy.table.QTable`.  The allowed column names are any of
-        the attributes of `SourceProperties`.
-
-    exclude_columns : str or list of str, optional
-        Names of columns to exclude from the default properties list in
-        the output `~astropy.table.QTable`.  The default properties are
-        those with scalar values.
-
-    Returns
-    -------
-    table : `~astropy.table.QTable`
-        A table of properties of the segmented sources, one row per
-        source.
-
-    See Also
-    --------
-    SegmentationImage, SourceProperties, source_properties, detect_sources
-    """
-
-    if ((isinstance(source_props, list) or
-         isinstance(source_props, SourceCatalog)) and len(source_props) == 0):
-            raise ValueError('source_props is an empty list')
-
-    source_props = np.atleast_1d(source_props)
-
-    # all scalar-valued properties
-    columns_all = ['id', 'xcentroid', 'ycentroid', 'sky_centroid',
-                   'sky_centroid_icrs', 'source_sum',
-                   'source_sum_err', 'background_sum', 'background_mean',
-                   'background_at_centroid', 'xmin', 'xmax', 'ymin', 'ymax',
-                   'min_value', 'max_value', 'minval_xpos', 'minval_ypos',
-                   'maxval_xpos', 'maxval_ypos', 'area', 'equivalent_radius',
-                   'perimeter', 'semimajor_axis_sigma',
-                   'semiminor_axis_sigma', 'eccentricity', 'orientation',
-                   'ellipticity', 'elongation', 'covar_sigx2',
-                   'covar_sigxy', 'covar_sigy2', 'cxx', 'cxy', 'cyy']
-
-    table_columns = None
-    if exclude_columns is not None:
-        table_columns = [s for s in columns_all if s not in exclude_columns]
-    if columns is not None:
-        table_columns = np.atleast_1d(columns)
-    if table_columns is None:
-        table_columns = columns_all
-
-    # For a large catalog, it's much faster to calculate world
-    # coordinates using the complete list of (x, y) instead of looping
-    # through the individual (x, y).  It's also much faster to recalculate
-    # world coordinates than to create a SkyCoord array from a
-    # loop-generated SkyCoord list.  The assumption here is that the wcs
-    # is the same for each element of source_props.
-    sky_colnames = ['sky_centroid', 'sky_centroid_icrs', 'icrs_centroid',
-                    'ra_icrs_centroid', 'dec_icrs_centroid']
-    calc_skycoords = any(sky_colname in table_columns
-                         for sky_colname in sky_colnames)
-
-    if calc_skycoords:
-        if source_props[0]._wcs is not None:
-            xcentroid = [props.xcentroid.value for props in source_props]
-            ycentroid = [props.ycentroid.value for props in source_props]
-
-            sky_centroid = pixel_to_skycoord(
-                xcentroid, ycentroid, source_props[0]._wcs, origin=0)
-            sky_centroid_icrs = sky_centroid.icrs
-            icrs_centroid = sky_centroid_icrs
-            ra_icrs_centroid = sky_centroid_icrs.ra.deg * u.deg
-            dec_icrs_centroid = sky_centroid_icrs.dec.deg * u.deg
-        else:
-            nprops = len(source_props)
-            sky_centroid = sky_centroid_icrs = [None] * nprops
-            icrs_centroid = [None] * nprops
-            ra_icrs_centroid = dec_icrs_centroid = [None] * nprops
-
-    bbox_colnames = ['sky_bbox_ll', 'sky_bbox_ul', 'sky_bbox_lr',
-                     'sky_bbox_ur']
-    calc_bboxcoords = any(bbox_colname in table_columns
-                          for bbox_colname in bbox_colnames)
-
-    if calc_bboxcoords:
-        if source_props[0]._wcs is not None:
-            xmin = np.array([props.xmin.value for props in source_props])
-            ymin = np.array([props.ymin.value for props in source_props])
-            xmax = np.array([props.xmax.value for props in source_props])
-            ymax = np.array([props.ymax.value for props in source_props])
-
-            wcs = source_props[0]._wcs
-            sky_bbox_ll = pixel_to_skycoord(xmin - 0.5, ymin - 0.5, wcs,
-                                            origin=0)
-            sky_bbox_ul = pixel_to_skycoord(xmin - 0.5, ymax + 0.5, wcs,
-                                            origin=0)
-            sky_bbox_lr = pixel_to_skycoord(xmax + 0.5, ymin - 0.5, wcs,
-                                            origin=0)
-            sky_bbox_ur = pixel_to_skycoord(xmax + 0.5, ymax + 0.5, wcs,
-                                            origin=0)
-        else:
-            nprops = len(source_props)
-            sky_bbox_ll = sky_bbox_ul = [None] * nprops
-            sky_bbox_lr = sky_bbox_ur = [None] * nprops
-
-    props_table = QTable()
-    for column in table_columns:
-        if column == 'sky_centroid':
-            props_table[column] = sky_centroid
-        elif column == 'sky_centroid_icrs':
-            props_table[column] = sky_centroid_icrs
-        elif column == 'icrs_centroid':
-            warnings.warn('The icrs_centroid property is deprecated and '
-                          'may be removed in a future version.  Use '
-                          'sky_centroid_icrs instead',
-                          AstropyDeprecationWarning)
-            props_table[column] = icrs_centroid
-        elif column == 'ra_icrs_centroid':
-            warnings.warn('The ra_icrs_centroid property is deprecated and '
-                          'may be removed in a future version.  Use '
-                          'sky_centroid_icrs.ra instead',
-                          AstropyDeprecationWarning)
-            props_table[column] = ra_icrs_centroid
-        elif column == 'dec_icrs_centroid':
-            warnings.warn('The dec_icrs_centroid property is deprecated and '
-                          'may be removed in a future version.  Use '
-                          'sky_centroid_icrs.dec instead',
-                          AstropyDeprecationWarning)
-            props_table[column] = dec_icrs_centroid
-        elif column == 'sky_bbox_ll':
-            props_table[column] = sky_bbox_ll
-        elif column == 'sky_bbox_ul':
-            props_table[column] = sky_bbox_ul
-        elif column == 'sky_bbox_lr':
-            props_table[column] = sky_bbox_lr
-        elif column == 'sky_bbox_ur':
-            props_table[column] = sky_bbox_ur
-        else:
-            values = [getattr(props, column) for props in source_props]
-            if isinstance(values[0], u.Quantity):
-                # turn list of Quantities into a Quantity array
-                values = u.Quantity(values)
-            if isinstance(values[0], SkyCoord):   # pragma: no cover
-                # turn list of SkyCoord into a SkyCoord array
-                values = SkyCoord(values)
-
-            props_table[column] = values
-
-    return props_table
