@@ -1,6 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 
 import numpy as np
 from numpy.testing import assert_allclose
@@ -29,7 +27,7 @@ except ImportError:
 
 @pytest.mark.skipif('not HAS_SCIPY')
 @pytest.mark.skipif('not HAS_SKIMAGE')
-class TestDeblendSources(object):
+class TestDeblendSources:
     def setup_class(self):
         g1 = models.Gaussian2D(100, 50, 50, 5, 5)
         g2 = models.Gaussian2D(100, 35, 50, 5, 5)
@@ -68,18 +66,30 @@ class TestDeblendSources(object):
         result = deblend_sources(data, segm, self.npixels)
         assert result.nlabels == 6
         assert result.nlabels == len(result.slices)
-        assert result.area(1) == result.area(2)
-        assert result.area(1) == result.area(3)
-        assert result.area(1) == result.area(4)
-        assert result.area(1) == result.area(5)
-        assert result.area(1) == result.area(6)
+        assert result.areas[0] == result.areas[1]
+        assert result.areas[0] == result.areas[2]
+        assert result.areas[0] == result.areas[3]
+        assert result.areas[0] == result.areas[4]
+        assert result.areas[0] == result.areas[5]
+
+    def test_deblend_multiple_sources_with_neighbor(self):
+        g1 = models.Gaussian2D(100, 50, 50, 20, 5, theta=45)
+        g2 = models.Gaussian2D(100, 35, 50, 5, 5)
+        g3 = models.Gaussian2D(100, 60, 20, 5, 5)
+
+        x = self.x
+        y = self.y
+        data = (g1 + g2 + g3)(x, y)
+        segm = detect_sources(data, self.threshold, self.npixels)
+        result = deblend_sources(data, segm, self.npixels)
+        assert result.nlabels == 3
 
     @pytest.mark.parametrize('mode', ['exponential', 'linear'])
     def test_deblend_sources_norelabel(self, mode):
         result = deblend_sources(self.data, self.segm, self.npixels,
                                  mode=mode, relabel=False)
         assert result.nlabels == 2
-        assert len(result.slices) <= result.max
+        assert len(result.slices) <= result.max_label
         assert len(result.slices) == 3   # label 1 is None
         assert_allclose(np.nonzero(self.segm), np.nonzero(result))
 
@@ -152,3 +162,14 @@ class TestDeblendSources(object):
         assert segm_deblend.nlabels == 1
         with pytest.raises(ValueError):
             deblend_sources(data, segm, npixels=1, connectivity=4)
+
+    def test_data_nan(self):
+        """
+        Test that deblending occurs even if the data within a segment
+        contains one or more NaNs.  Regression test for #658.
+        """
+
+        data = self.data.copy()
+        data[50, 50] = np.nan
+        segm2 = deblend_sources(data, self.segm, 5)
+        assert segm2.nlabels == 2
