@@ -1,6 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 
 import numpy as np
 from numpy.testing import assert_array_equal, assert_allclose
@@ -20,15 +18,9 @@ try:
 except ImportError:
     HAS_SCIPY = False
 
-try:
-    import skimage    # noqa
-    HAS_SKIMAGE = True
-except ImportError:
-    HAS_SKIMAGE = False
-
 
 @pytest.mark.skipif('not HAS_SCIPY')
-class TestDetectSources(object):
+class TestDetectSources:
     def setup_class(self):
         self.data = np.array([[0, 1, 0], [0, 2, 0],
                               [0, 0, 0]]).astype(np.float)
@@ -52,6 +44,39 @@ class TestDetectSources(object):
         segm = detect_sources(self.data, threshold=0.9, npixels=5)
         assert_array_equal(segm.data, self.ref1)
 
+    def test_npixels(self):
+        """
+        Test removal of sources whose size is less than npixels.
+        Regression tests for #663.
+        """
+
+        data = np.zeros((8, 8))
+        data[0:4, 0] = 1
+        data[0, 0:4] = 1
+        data[3, 3:] = 2
+        data[3:, 3] = 2
+
+        segm = detect_sources(data, 0, npixels=8)
+        assert(segm.nlabels == 1)
+        segm = detect_sources(data, 0, npixels=9)
+        assert(segm.nlabels == 1)
+
+        data = np.zeros((8, 8))
+        data[0:4, 0] = 1
+        data[0, 0:4] = 1
+        data[3, 2:] = 2
+        data[3:, 2] = 2
+        data[5:, 3] = 2
+
+        npixels = np.arange(9, 14)
+        for npixels in np.arange(9, 14):
+            segm = detect_sources(data, 0, npixels=npixels)
+            assert(segm.nlabels == 1)
+            assert(segm.areas[0] == 13)
+
+        segm = detect_sources(data, 0, npixels=14)
+        assert(segm.nlabels == 0)
+
     def test_zerothresh(self):
         """Test detection with zero threshold."""
 
@@ -126,9 +151,22 @@ class TestDetectSources(object):
             assert ('The kernel is not normalized.'
                     in str(warning_lines[0].message))
 
+    def test_mask(self):
+        data = np.zeros((11, 11))
+        data[3:8, 3:8] = 5.
+        mask = np.zeros_like(data, dtype=bool)
+        mask[4:6, 4:6] = True
+        segm1 = detect_sources(data, 1., 1.)
+        segm2 = detect_sources(data, 1., 1., mask=mask)
+        assert segm2.areas[0] == segm1.areas[0] - mask.sum()
+
+    def test_mask_shape(self):
+        with pytest.raises(ValueError):
+            detect_sources(self.data, 1., 1., mask=np.ones((5, 5)))
+
 
 @pytest.mark.skipif('not HAS_SCIPY')
-class TestMakeSourceMask(object):
+class TestMakeSourceMask:
     def setup_class(self):
         self.data = make_4gaussians_image()
 
