@@ -14,7 +14,7 @@ from astropy.utils.misc import isiterable
 import astropy.wcs as WCS
 
 from ..properties import (SegmentationImage, SourceProperties,
-                          source_properties, SourceCatalog, properties_table)
+                          source_properties, SourceCatalog)
 
 try:
     import scipy    # noqa
@@ -88,13 +88,9 @@ class TestSourceProperties:
     def test_to_table(self):
         props = SourceProperties(IMAGE, SEGM, label=1)
         t1 = props.to_table()
-        t2 = properties_table(props)
         assert isinstance(t1, QTable)
-        assert isinstance(t2, QTable)
         assert len(t1) == 1
-        props = ['xcentroid', 'ycentroid', 'source_sum']
-        for prop in props:
-            assert t1[prop] == t2[prop]
+        assert_quantity_allclose(t1['area'], 1058 * u.pix**2)
 
 
 @pytest.mark.skipif('not HAS_SKIMAGE')
@@ -402,6 +398,21 @@ class TestSourceCatalog:
         assert t[0]['sky_centroid'] is not None
         assert t.colnames == columns
 
+        obj = cat[0]
+        row = t[0]
+        assert_quantity_allclose(obj.sky_bbox_ll.ra, row['sky_bbox_ll'].ra)
+        assert_quantity_allclose(obj.sky_bbox_ll.dec, row['sky_bbox_ll'].dec)
+
+        assert_quantity_allclose(obj.sky_bbox_ul.ra, row['sky_bbox_ul'].ra)
+        assert_quantity_allclose(obj.sky_bbox_ul.dec, row['sky_bbox_ul'].dec)
+
+        assert_quantity_allclose(obj.sky_bbox_lr.ra, row['sky_bbox_lr'].ra)
+        assert_quantity_allclose(obj.sky_bbox_lr.dec, row['sky_bbox_lr'].dec)
+
+        assert_quantity_allclose(obj.sky_bbox_ur.ra, row['sky_bbox_ur'].ra)
+        assert_quantity_allclose(obj.sky_bbox_ur.dec, row['sky_bbox_ur'].dec)
+
+    def test_table_no_wcs(self):
         cat = source_properties(IMAGE, SEGM)
         columns = ['sky_centroid', 'sky_centroid_icrs', 'icrs_centroid',
                    'ra_icrs_centroid', 'dec_icrs_centroid', 'sky_bbox_ll',
@@ -409,61 +420,3 @@ class TestSourceCatalog:
         t = cat.to_table(columns=columns)
         assert t[0]['sky_centroid'] is None
         assert t.colnames == columns
-
-
-@pytest.mark.skipif('not HAS_SKIMAGE')
-@pytest.mark.skipif('not HAS_SCIPY')
-class TestPropertiesTable:
-    def test_properties_table(self):
-        props = source_properties(IMAGE, SEGM)
-        t = properties_table(props)
-        assert isinstance(t, QTable)
-        assert len(t) == 1
-
-    def test_properties_table_include(self):
-        props = source_properties(IMAGE, SEGM)
-        columns = ['id', 'xcentroid']
-        t = properties_table(props, columns=columns)
-        assert isinstance(t, QTable)
-        assert len(t) == 1
-        assert t.colnames == columns
-
-    def test_properties_table_include_invalidname(self):
-        props = source_properties(IMAGE, SEGM)
-        columns = ['idzz', 'xcentroidzz']
-        with pytest.raises(AttributeError):
-            properties_table(props, columns=columns)
-
-    def test_properties_table_exclude(self):
-        props = source_properties(IMAGE, SEGM)
-        exclude = ['id', 'xcentroid']
-        t = properties_table(props, exclude_columns=exclude)
-        assert isinstance(t, QTable)
-        assert len(t) == 1
-        with pytest.raises(KeyError):
-            t['id']
-
-    def test_properties_table_empty_props(self):
-        props = source_properties(IMAGE, SEGM, labels=-1)
-        with pytest.raises(ValueError):
-            properties_table(props)
-
-    def test_properties_table_empty_list(self):
-        with pytest.raises(ValueError):
-            properties_table([])
-
-    def test_properties_table_wcs(self):
-        mywcs = WCS.WCS(naxis=2)
-        rho = np.pi / 3.
-        scale = 0.1 / 3600.
-        mywcs.wcs.cd = [[scale*np.cos(rho), -scale*np.sin(rho)],
-                        [scale*np.sin(rho), scale*np.cos(rho)]]
-        mywcs.wcs.ctype = ['RA---TAN', 'DEC--TAN']
-
-        props = source_properties(IMAGE, SEGM, wcs=mywcs)
-        columns = ['sky_centroid', 'sky_centroid_icrs', 'icrs_centroid',
-                   'ra_icrs_centroid', 'dec_icrs_centroid', 'sky_bbox_ll',
-                   'sky_bbox_ul', 'sky_bbox_lr', 'sky_bbox_ur']
-        t = properties_table(props, columns=columns)
-        assert t.colnames == columns
-        assert t[0]['sky_centroid_icrs'] is not None
