@@ -10,7 +10,7 @@ from astropy.utils import deprecated
 __all__ = ['cutout_footprint']
 
 
-@deprecated(0.5)
+@deprecated('0.5')
 def cutout_footprint(data, position, box_size=3, footprint=None, mask=None,
                      error=None):
     """
